Rename ActionExitCode to ErrorCode

Nowadays ActionExitCode is used throughout the codebase so use a more
generic name to reflect this.

BUG=chromium:216507
TEST=unit tests pass

Change-Id: I23d1d7e2676443251dbc42ed137fd018aadfa8a3
Reviewed-on: https://gerrit.chromium.org/gerrit/49512
Reviewed-by: Don Garrett <dgarrett@chromium.org>
Commit-Queue: David Zeuthen <zeuthen@chromium.org>
Tested-by: David Zeuthen <zeuthen@chromium.org>
diff --git a/update_attempter.h b/update_attempter.h
index bcd730f..315e545 100644
--- a/update_attempter.h
+++ b/update_attempter.h
@@ -79,11 +79,11 @@
                       bool is_test_mode);
 
   // ActionProcessorDelegate methods:
-  void ProcessingDone(const ActionProcessor* processor, ActionExitCode code);
+  void ProcessingDone(const ActionProcessor* processor, ErrorCode code);
   void ProcessingStopped(const ActionProcessor* processor);
   void ActionCompleted(ActionProcessor* processor,
                        AbstractAction* action,
-                       ActionExitCode code);
+                       ErrorCode code);
 
   // Stop updating. An attempt will be made to record status to the disk
   // so that updates can be resumed later.
@@ -153,7 +153,7 @@
   // Broadcasts the current status over D-Bus.
   void BroadcastStatus();
 
   // Returns the special flags to be added to ActionExitCode values based on the
   // parameters used in the current update attempt.
   uint32_t GetErrorCodeFlags();
 
@@ -161,7 +161,7 @@
   // current state of the system, in which case |cancel_reason| indicates the
   // reason for the cancellation.  False otherwise, in which case
   // |cancel_reason| is untouched.
-  bool ShouldCancel(ActionExitCode* cancel_reason);
+  bool ShouldCancel(ErrorCode* cancel_reason);
 
  private:
   // Update server URL for automated lab test.
@@ -191,7 +191,7 @@
 
   // Creates an error event object in |error_event_| to be included in an
   // OmahaRequestAction once the current action processor is done.
-  void CreatePendingErrorEvent(AbstractAction* action, ActionExitCode code);
+  void CreatePendingErrorEvent(AbstractAction* action, ErrorCode code);
 
   // If there's a pending error event allocated in |error_event_|, schedules an
   // OmahaRequestAction with that event in the current processor, clears the
@@ -153,7 +153,7 @@
   void BroadcastStatus();
 
-  // Returns the special flags to be added to ActionExitCode values based on the
+  // Returns the special flags to be added to ErrorCode values based on the
   // parameters used in the current update attempt.
   uint32_t GetErrorCodeFlags();